@@ -20,20 +20,18 @@
   See the License for the specific language governing permissions and
   limitations under the License.
  */
-#ifndef _P_RefCountCache_h_
-#define _P_RefCountCache_h_
+#pragma once
 
 #include <I_EventSystem.h>
 #include <P_EventSystem.h> // TODO: less? just need ET_TASK
 
-#include <ts/Map.h>
-#include <ts/PriorityQueue.h>
+#include "tscore/Map.h"
+#include "tscore/PriorityQueue.h"
 
-#include <ts/List.h>
-#include <ts/ink_hrtime.h>
+#include "tscore/List.h"
+#include "tscore/ink_hrtime.h"
 
-#include <ts/Vec.h>
-#include <ts/I_Version.h>
+#include "tscore/I_Version.h"
 #include <unistd.h>
 
 #define REFCOUNT_CACHE_EVENT_SYNC REFCOUNT_CACHE_EVENT_EVENTS_START
@@ -79,23 +77,40 @@ public:
   PriorityQueueEntry<RefCountCacheHashEntry *> *expiry_entry;
   RefCountCacheItemMeta meta;
 
+  // Need a no-argument constructor to use the classAllocator
+  RefCountCacheHashEntry() : item(Ptr<RefCountObj>()), expiry_entry(nullptr), meta(0, 0) {}
   void
   set(RefCountObj *i, uint64_t key, unsigned int size, int expire_time)
   {
     this->item = make_ptr(i);
     this->meta = RefCountCacheItemMeta(key, size, expire_time);
-  };
-  // Need a no-argument constructor to use the classAllocator
-  RefCountCacheHashEntry() : item(Ptr<RefCountObj>()), expiry_entry(NULL), meta(0, 0) {}
+  }
+
   // make these values comparable -- so we can sort them
   bool
   operator<(const RefCountCacheHashEntry &v2) const
   {
     return this->meta.expiry_time < v2.meta.expiry_time;
-  };
+  }
+
+  static RefCountCacheHashEntry *alloc();
+  static void dealloc(RefCountCacheHashEntry *e);
+
+  template <typename C>
+  static void
+  free(RefCountCacheHashEntry *e)
+  {
+    // Since the Value is actually RefCountObj-- when this gets deleted normally it calls the wrong
+    // `free` method, this forces the delete/decr to happen with the right type
+    Ptr<C> *tmp = (Ptr<C> *)&e->item;
+    tmp->clear();
+
+    e->~RefCountCacheHashEntry();
+    dealloc(e);
+  }
 };
+
 // Since the hashing values are all fixed size, we can simply use a classAllocator to avoid mallocs
-extern ClassAllocator<RefCountCacheHashEntry> refCountCacheHashingValueAllocator;
 extern ClassAllocator<PriorityQueueEntry<RefCountCacheHashEntry *>> expiryQueueEntry;
 
 struct RefCountCacheHashing {
@@ -126,7 +141,7 @@ struct RefCountCacheHashing {
 template <class C> class RefCountCachePartition
 {
 public:
-  RefCountCachePartition(unsigned int part_num, uint64_t max_size, unsigned int max_items, RecRawStatBlock *rsb = NULL);
+  RefCountCachePartition(unsigned int part_num, uint64_t max_size, unsigned int max_items, RecRawStatBlock *rsb = nullptr);
   Ptr<C> get(uint64_t key);
   void put(uint64_t key, C *item, int size = 0, int expire_time = 0);
   void erase(uint64_t key, ink_time_t expiry_time = -1);
@@ -134,9 +149,10 @@ public:
   void clear();
   bool is_full() const;
   bool make_space_for(unsigned int);
+  template <class Iterator> void dealloc_entry(Iterator ptr);
 
   size_t count() const;
-  void copy(Vec<RefCountCacheHashEntry *> &items);
+  void copy(std::vector<RefCountCacheHashEntry *> &items);
 
   typedef typename TSHashTable<RefCountCacheHashing>::iterator iterator_type;
   typedef typename TSHashTable<RefCountCacheHashing>::self hash_type;
@@ -199,7 +215,7 @@ RefCountCachePartition<C>::put(uint64_t key, C *item, int size, int expire_time)
   }
 
   // Create our value-- which has a ref to the `item`
-  RefCountCacheHashEntry *val = refCountCacheHashingValueAllocator.alloc();
+  RefCountCacheHashEntry *val = RefCountCacheHashEntry::alloc();
   val->set(item, key, size, expire_time);
 
   // add expiry_entry to expiry queue, if the expire time is positive (otherwise it means don't expire)
@@ -228,31 +244,38 @@ RefCountCachePartition<C>::erase(uint64_t key, ink_time_t expiry_time)
     if (expiry_time >= 0 && l.m_value->meta.expiry_time != expiry_time) {
       return;
     }
+
     // TSHashMap does NOT clean up the item-- this remove just removes it from the map
     // we are responsible for cleaning it up here
     this->item_map.remove(l);
+    this->dealloc_entry(l);
+  }
+}
 
-    // decrement usage counters
-    this->size -= l.m_value->meta.size;
+template <class C>
+template <class Iterator>
+void
+RefCountCachePartition<C>::dealloc_entry(Iterator ptr)
+{
+  if (ptr.m_value) {
+    // decrement usag are not cleaned up. The values are not touched in this method, therefore it is safe
+    // counters
+    this->size -= ptr->meta.size;
     this->items--;
 
-    this->metric_inc(refcountcache_current_size_stat, -((int64_t)l.m_value->meta.size));
+    this->metric_inc(refcountcache_current_size_stat, -((int64_t)ptr->meta.size));
     this->metric_inc(refcountcache_current_items_stat, -1);
 
     // remove from expiry queue
-    if (l.m_value->expiry_entry != NULL) {
-      Debug("refcountcache", "partition %d deleting item from expiry_queue idx=%d\n", this->part_num,
-            l.m_value->expiry_entry->index);
-      this->expiry_queue.erase(l.m_value->expiry_entry);
-      expiryQueueEntry.free(l.m_value->expiry_entry);
-      l.m_value->expiry_entry = NULL; // To avoid the destruction of `l` calling the destructor again-- and causing issues
+    if (ptr->expiry_entry != nullptr) {
+      Debug("refcountcache", "partition %d deleting item from expiry_queue idx=%d", this->part_num, ptr->expiry_entry->index);
+
+      this->expiry_queue.erase(ptr->expiry_entry);
+      expiryQueueEntry.free(ptr->expiry_entry);
+      ptr->expiry_entry = nullptr; // To avoid the destruction of `l` calling the destructor again-- and causing issues
     }
-    // Since the Value is actually RefCountObj-- when this gets deleted normally it calls the wrong
-    // `free` method, this forces the delete/decr to happen with the right type
-    Ptr<C> *tmp = (Ptr<C> *)&l.m_value->item;
-    tmp->clear();
-    l.m_value->~RefCountCacheHashEntry();
-    refCountCacheHashingValueAllocator.free(l.m_value);
+
+    RefCountCacheHashEntry::free<C>(ptr.m_value);
   }
 }
 
@@ -260,10 +283,15 @@ template <class C>
 void
 RefCountCachePartition<C>::clear()
 {
-  // this->item_map.clear() doesn't clean up anything, so instead of using that we'll iterate
-  // over every item and then call delete
-  for (RefCountCachePartition<C>::iterator_type i = this->item_map.begin(); i != this->item_map.end(); ++i) {
-    this->erase(i.m_value->meta.key, i.m_value->meta.expiry_time);
+  // Since the hash nodes embed the list pointers, you can't iterate over the
+  // hash elements and deallocate them, let alone remove them from the hash.
+  // Hence, this monstrosity.
+  while (this->item_map.count() > 0) {
+    location_type pos = this->item_map.find(this->item_map.begin().m_value);
+
+    ink_assert(pos.isValid());
+    this->item_map.remove(pos);
+    this->dealloc_entry(pos);
   }
 }
 
@@ -286,7 +314,7 @@ RefCountCachePartition<C>::make_space_for(unsigned int size)
   while (this->is_full() || (size > 0 && this->size + size > this->max_size)) {
     PriorityQueueEntry<RefCountCacheHashEntry *> *top_item = expiry_queue.top();
     // if there is nothing in the expiry queue, then we can't make space
-    if (top_item == NULL) {
+    if (top_item == nullptr) {
       return false;
     }
 
@@ -309,10 +337,10 @@ RefCountCachePartition<C>::count() const
 
 template <class C>
 void
-RefCountCachePartition<C>::copy(Vec<RefCountCacheHashEntry *> &items)
+RefCountCachePartition<C>::copy(std::vector<RefCountCacheHashEntry *> &items)
 {
   for (RefCountCachePartition<C>::iterator_type i = this->item_map.begin(); i != this->item_map.end(); ++i) {
-    RefCountCacheHashEntry *val = refCountCacheHashingValueAllocator.alloc();
+    RefCountCacheHashEntry *val = RefCountCacheHashEntry::alloc();
     val->set(i.m_value->item.get(), i.m_value->meta.key, i.m_value->meta.size, i.m_value->meta.expiry_time);
     items.push_back(val);
   }
@@ -389,7 +417,7 @@ private:
   int max_size;  // Total size
   int max_items; // Total number of items allowed
   unsigned int num_partitions;
-  Vec<RefCountCachePartition<C> *> partitions;
+  std::vector<RefCountCachePartition<C> *> partitions;
   // Header
   RefCountCacheHeader header; // Our header
   RecRawStatBlock *rsb;
@@ -398,7 +426,7 @@ private:
 template <class C>
 RefCountCache<C>::RefCountCache(unsigned int num_partitions, int size, int items, VersionNumber object_version,
                                 std::string metrics_prefix)
-  : header(RefCountCacheHeader(object_version)), rsb(NULL)
+  : header(RefCountCacheHeader(object_version)), rsb(nullptr)
 {
   this->max_size       = size;
   this->max_items      = items;
@@ -444,7 +472,10 @@ RefCountCache<C>::RefCountCache(unsigned int num_partitions, int size, int items
 // Deconstruct the class
 template <class C> RefCountCache<C>::~RefCountCache()
 {
-  delete this->partitions;
+  for (unsigned int i = 0; i < num_partitions; i++) {
+    delete this->partitions[i];
+  }
+  num_partitions = 0;
 }
 
 template <class C>
@@ -539,13 +570,14 @@ LoadRefCountCacheFromPath(RefCountCache<CacheEntryType> &cache, std::string dirn
                           CacheEntryType *(*load_func)(char *, unsigned int))
 {
   // If we have no load method, then we can't load anything so lets just stop right here
-  if (load_func == NULL) {
+  if (load_func == nullptr) {
     return -1; // TODO: some specific error code
   }
 
   int fd = open(filepath.c_str(), O_RDONLY);
   if (fd < 0) {
-    return -1; // specific code for missing?
+    Warning("Unable to open file %s; [Error]: %s", filepath.c_str(), strerror(errno));
+    return -1;
   }
 
   // read in the header
@@ -576,7 +608,7 @@ LoadRefCountCacheFromPath(RefCountCache<CacheEntryType> &cache, std::string dirn
     }
 
     CacheEntryType *newItem = load_func((char *)&buf, tmpValue.size);
-    if (newItem != NULL) {
+    if (newItem != nullptr) {
       cache.put(tmpValue.key, newItem, tmpValue.size - sizeof(CacheEntryType));
     }
   };
@@ -584,5 +616,3 @@ LoadRefCountCacheFromPath(RefCountCache<CacheEntryType> &cache, std::string dirn
   socketManager.close(fd);
   return 0;
 }
-
-#endif /* _P_RefCountCache_h_ */
