@@ -21,16 +21,16 @@
   limitations under the License.
  */
 
-#include "ts/ink_platform.h"
-#include "ts/HashFNV.h"
-#include "ts/Diags.h"
-#include "ts/ink_memory.h"
-#include <stdio.h>
-#include "ts/Allocator.h"
+#include "tscore/ink_platform.h"
+#include "tscore/HashFNV.h"
+#include "tscore/Diags.h"
+#include "tscore/ink_memory.h"
+#include <cstdio>
+#include "tscore/Allocator.h"
 #include "HTTP.h"
 #include "HdrToken.h"
 #include "MIME.h"
-#include "ts/Regex.h"
+#include "tscore/Regex.h"
 #include "URL.h"
 
 /*
@@ -104,11 +104,13 @@ static const char *_hdrtoken_strs[] = {
   "rtsp", "mmsu", "mmst", "mms", "wss", "ws",
 
   // HTTP methods
-  "CONNECT", "DELETE", "GET", "POST", "HEAD", "ICP_QUERY", "OPTIONS", "PURGE", "PUT", "TRACE", "PUSH",
+  "CONNECT", "DELETE", "GET", "POST", "HEAD", "OPTIONS", "PURGE", "PUT", "TRACE", "PUSH",
 
   // Header extensions
   "X-ID", "X-Forwarded-For", "TE", "Strict-Transport-Security", "100-continue",
-};
+
+  // RFC-2739
+  "Forwarded"};
 
 static HdrTokenTypeBinding _hdrtoken_strs_type_initializers[] = {
   {"file", HDRTOKEN_TYPE_SCHEME},
@@ -136,7 +138,6 @@ static HdrTokenTypeBinding _hdrtoken_strs_type_initializers[] = {
   {"DELETE", HDRTOKEN_TYPE_METHOD},
   {"GET", HDRTOKEN_TYPE_METHOD},
   {"HEAD", HDRTOKEN_TYPE_METHOD},
-  {"ICP_QUERY", HDRTOKEN_TYPE_METHOD},
   {"OPTIONS", HDRTOKEN_TYPE_METHOD},
   {"POST", HDRTOKEN_TYPE_METHOD},
   {"PURGE", HDRTOKEN_TYPE_METHOD},
@@ -158,7 +159,7 @@ static HdrTokenTypeBinding _hdrtoken_strs_type_initializers[] = {
   {"s-maxage", HDRTOKEN_TYPE_CACHE_CONTROL},
   {"need-revalidate-once", HDRTOKEN_TYPE_CACHE_CONTROL},
 
-  {(char *)NULL, (HdrTokenType)0},
+  {(char *)nullptr, (HdrTokenType)0},
 };
 
 static HdrTokenFieldInfo _hdrtoken_strs_field_initializers[] = {
@@ -224,7 +225,8 @@ static HdrTokenFieldInfo _hdrtoken_strs_field_initializers[] = {
   {"Subject", MIME_SLOTID_NONE, MIME_PRESENCE_SUBJECT, HTIF_NONE},
   {"Summary", MIME_SLOTID_NONE, MIME_PRESENCE_SUMMARY, HTIF_NONE},
   {"TE", MIME_SLOTID_TE, MIME_PRESENCE_TE, (HTIF_COMMAS | HTIF_MULTVALS | HTIF_HOPBYHOP)},
-  {"Transfer-Encoding", MIME_SLOTID_TRANSFER_ENCODING, MIME_PRESENCE_TRANSFER_ENCODING, (HTIF_COMMAS | HTIF_MULTVALS)},
+  {"Transfer-Encoding", MIME_SLOTID_TRANSFER_ENCODING, MIME_PRESENCE_TRANSFER_ENCODING,
+   (HTIF_COMMAS | HTIF_MULTVALS | HTIF_HOPBYHOP)},
   {"Upgrade", MIME_SLOTID_NONE, MIME_PRESENCE_UPGRADE, (HTIF_COMMAS | HTIF_MULTVALS | HTIF_HOPBYHOP)},
   {"User-Agent", MIME_SLOTID_USER_AGENT, MIME_PRESENCE_USER_AGENT, HTIF_NONE},
   {"Vary", MIME_SLOTID_VARY, MIME_PRESENCE_VARY, (HTIF_COMMAS | HTIF_MULTVALS)},
@@ -234,13 +236,14 @@ static HdrTokenFieldInfo _hdrtoken_strs_field_initializers[] = {
   {"Xref", MIME_SLOTID_NONE, MIME_PRESENCE_XREF, HTIF_NONE},
   {"X-ID", MIME_SLOTID_NONE, MIME_PRESENCE_NONE, (HTIF_COMMAS | HTIF_MULTVALS | HTIF_HOPBYHOP)},
   {"X-Forwarded-For", MIME_SLOTID_NONE, MIME_PRESENCE_NONE, (HTIF_COMMAS | HTIF_MULTVALS)},
+  {"Forwarded", MIME_SLOTID_NONE, MIME_PRESENCE_NONE, (HTIF_COMMAS | HTIF_MULTVALS)},
   {"Sec-WebSocket-Key", MIME_SLOTID_NONE, MIME_PRESENCE_NONE, HTIF_NONE},
   {"Sec-WebSocket-Version", MIME_SLOTID_NONE, MIME_PRESENCE_NONE, HTIF_NONE},
-  {NULL, 0, 0, 0},
+  {nullptr, 0, 0, 0},
 };
 
-const char *_hdrtoken_strs_heap_f = NULL; // storage first byte
-const char *_hdrtoken_strs_heap_l = NULL; // storage last byte
+const char *_hdrtoken_strs_heap_f = nullptr; // storage first byte
+const char *_hdrtoken_strs_heap_l = nullptr; // storage last byte
 
 int hdrtoken_num_wks = SIZEOF(_hdrtoken_strs); // # of well-known strings
 
@@ -251,7 +254,7 @@ int32_t hdrtoken_str_slotids[SIZEOF(_hdrtoken_strs)];          // wks_idx -> slo
 uint64_t hdrtoken_str_masks[SIZEOF(_hdrtoken_strs)];           // wks_idx -> presence mask
 uint32_t hdrtoken_str_flags[SIZEOF(_hdrtoken_strs)];           // wks_idx -> flags
 
-DFA *hdrtoken_strs_dfa = NULL;
+DFA *hdrtoken_strs_dfa = nullptr;
 
 /***********************************************************************
  *                                                                     *
@@ -260,7 +263,6 @@ DFA *hdrtoken_strs_dfa = NULL;
  ***********************************************************************/
 
 #define HDRTOKEN_HASH_TABLE_SIZE 65536
-#define HDRTOKEN_HASH_TABLE_MASK HDRTOKEN_HASH_TABLE_SIZE - 1
 
 struct HdrTokenHashBucket {
   const char *wks;
@@ -292,6 +294,9 @@ hdrtoken_hash(const unsigned char *string, unsigned int length)
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
+// WARNING:  Indexes into this array are stored on disk for cached objects.  New strings must be added at the end of the array to
+// avoid changing the indexes of pre-existing entries, unless the cache format version number is increased.
+//
 static const char *_hdrtoken_commonly_tokenized_strs[] = {
   // MIME Field names
   "Accept-Charset", "Accept-Encoding", "Accept-Language", "Accept-Ranges", "Accept", "Age", "Allow",
@@ -349,11 +354,13 @@ static const char *_hdrtoken_commonly_tokenized_strs[] = {
   "rtsp", "mmsu", "mmst", "mms", "wss", "ws",
 
   // HTTP methods
-  "CONNECT", "DELETE", "GET", "POST", "HEAD", "ICP_QUERY", "OPTIONS", "PURGE", "PUT", "TRACE", "PUSH",
+  "CONNECT", "DELETE", "GET", "POST", "HEAD", "OPTIONS", "PURGE", "PUT", "TRACE", "PUSH",
 
   // Header extensions
   "X-ID", "X-Forwarded-For", "TE", "Strict-Transport-Security", "100-continue",
-};
+
+  // RFC-2739
+  "Forwarded"};
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
@@ -408,7 +415,7 @@ snap_up_to_multiple(unsigned int n, unsigned int unit)
 }
 
 /**
-*/
+ */
 void
 hdrtoken_init()
 {
@@ -450,7 +457,7 @@ hdrtoken_init()
       prefix.wks_idx         = i;
       prefix.wks_length      = hdrtoken_str_lengths[i];
       prefix.wks_token_type  = HDRTOKEN_TYPE_OTHER; // default, can override later
-      prefix.wks_info.name   = NULL;                // default, can override later
+      prefix.wks_info.name   = nullptr;             // default, can override later
       prefix.wks_info.slotid = MIME_SLOTID_NONE;    // default, can override later
       prefix.wks_info.mask   = TOK_64_CONST(0);     // default, can override later
       prefix.wks_info.flags  = MIME_FLAGS_MULTVALS; // default, can override later
@@ -467,7 +474,7 @@ hdrtoken_init()
     }
 
     // Set the token types for certain tokens
-    for (i = 0; _hdrtoken_strs_type_initializers[i].name != NULL; i++) {
+    for (i = 0; _hdrtoken_strs_type_initializers[i].name != nullptr; i++) {
       int wks_idx;
       HdrTokenHeapPrefix *prefix;
 
@@ -481,7 +488,7 @@ hdrtoken_init()
     }
 
     // Set special data for field names
-    for (i = 0; _hdrtoken_strs_field_initializers[i].name != NULL; i++) {
+    for (i = 0; _hdrtoken_strs_field_initializers[i].name != nullptr; i++) {
       int wks_idx;
       HdrTokenHeapPrefix *prefix;
 
@@ -525,7 +532,7 @@ hdrtoken_tokenize_dfa(const char *string, int string_len, const char **wks_strin
     if (wks_idx >= 0) {
       *wks_string_out = hdrtoken_index_to_wks(wks_idx);
     } else {
-      *wks_string_out = NULL;
+      *wks_string_out = nullptr;
     }
   }
   // printf("hdrtoken_tokenize_dfa(%d,*s) - return %d\n",string_len,string,wks_idx);
@@ -542,7 +549,7 @@ hdrtoken_tokenize(const char *string, int string_len, const char **wks_string_ou
   int wks_idx;
   HdrTokenHashBucket *bucket;
 
-  ink_assert(string != NULL);
+  ink_assert(string != nullptr);
 
   if (hdrtoken_is_wks(string)) {
     wks_idx = hdrtoken_wks_to_index(string);
@@ -556,7 +563,7 @@ hdrtoken_tokenize(const char *string, int string_len, const char **wks_string_ou
   uint32_t slot = hash_to_slot(hash);
 
   bucket = &(hdrtoken_hash_table[slot]);
-  if ((bucket->wks != NULL) && (bucket->hash == hash) && (hdrtoken_wks_to_length(bucket->wks) == string_len)) {
+  if ((bucket->wks != nullptr) && (bucket->hash == hash) && (hdrtoken_wks_to_length(bucket->wks) == string_len)) {
     wks_idx = hdrtoken_wks_to_index(bucket->wks);
     if (wks_string_out) {
       *wks_string_out = bucket->wks;
@@ -574,7 +581,7 @@ hdrtoken_tokenize(const char *string, int string_len, const char **wks_string_ou
 const char *
 hdrtoken_string_to_wks(const char *string)
 {
-  const char *wks = NULL;
+  const char *wks = nullptr;
   hdrtoken_tokenize(string, (int)strlen(string), &wks);
   return wks;
 }
@@ -585,7 +592,7 @@ hdrtoken_string_to_wks(const char *string)
 const char *
 hdrtoken_string_to_wks(const char *string, int length)
 {
-  const char *wks = NULL;
+  const char *wks = nullptr;
   hdrtoken_tokenize(string, length, &wks);
   return wks;
 }
